@@ -59,7 +59,7 @@ def getInput(config, one_seq=False):
         cross_feature_input = layers.Lambda(lambda x: tf.SparseTensor(indices=x[0], values=x[1], dense_shape=[tf.shape(sequence_id_input)[0], cross_feature_num])) \
             ([cross_feature_indices, cross_feature_values])
     else:
-        cross_feature_input = layers.Input(shape=(cross_feature_num,), dtype='float32', sparse=True, name='cross_feature_input', batch_size=batchsize)
+        cross_feature_input = layers.Input(shape=(cross_feature_num,), dtype='float32', sparse=True, name='cross_feature_input')
 
     user_feature_input = layers.Input(shape=(user_feature_num,), dtype='int64', name='user_feature_input')
     # user_feature_input = Input(tensor=tf.zeros([tf.shape(sequence_id_input)[0], 12], dtype='int32'), name='user_feature_input')
