@@ -53,9 +53,7 @@ def compile_model(model, config):
     for var in tf.all_variables():
         try:
             sess.run(var)
-        except tf.errors.FailedPreconditionError:
-            uninit_vars.append(var)
-        except tf.python.framework.errors_impl.FailedPreconditionError:
+        except (tf.errors.FailedPreconditionError,tf.python.framework.errors_impl.FailedPreconditionError) as reason:
             uninit_vars.append(var)
     init_new_vars_op = tf.initialize_variables(uninit_vars)
     sess.run(init_new_vars_op)
