@@ -26,7 +26,7 @@ def datadownload(user_sql, conn_type='impala'):
     handler = ImpalaUtils(conn_type=conn_type)
     # USER_QUERY_SQL = open(sqlfile,'r',encoding='utf8').read()
     # user_sql = user_sql.replace('2019-01-01',ds)
-    print('datadownload: ', user_sql)
+    # print('datadownload: ', user_sql)
     df = handler.exec_sql_query_pandas(sql=user_sql)
     handler.close_conn()
     return df
