@@ -35,7 +35,7 @@ def dataupload2hdfs(data, file, sep='\t'):
                 try:
                     writer.write(ss)
                     # client.write(BASEDIR + file, data=ss, append=False, overwrite=False, encoding='utf8')
-                    print(('data upload 2 hdfs %d (%s times), ' + BASEDIR + file) % ((i + 1) * length, (str(6 - tries))))
+                    # print(('data upload 2 hdfs %d (%s times), ' + BASEDIR + file) % ((i + 1) * length, (str(6 - tries))))
                     break
                 except:
                     err = traceback.format_exc()
